@@ -20,12 +20,15 @@ from rest_framework.views import APIView
 from drf_spectacular.authentication import OpenApiAuthenticationExtension
 from drf_spectacular.contrib import *  # noqa: F403, F401
 from drf_spectacular.drainage import get_override, has_override
-from drf_spectacular.extensions import OpenApiSerializerExtension, OpenApiSerializerFieldExtension
+from drf_spectacular.extensions import (
+    OpenApiFilterExtension, OpenApiSerializerExtension, OpenApiSerializerFieldExtension,
+)
 from drf_spectacular.plumbing import (
     ComponentRegistry, ResolvedComponent, UnableToProceedError, anyisinstance, append_meta,
-    build_array_type, build_basic_type, build_choice_field, build_object_type, build_parameter_type,
-    error, follow_field_source, force_instance, get_doc, get_view_model, is_basic_type, is_field,
-    is_serializer, resolve_regex_path_parameter, resolve_type_hint, safe_ref, warn,
+    build_array_type, build_basic_type, build_choice_field, build_examples_list,
+    build_media_type_object, build_object_type, build_parameter_type, error, follow_field_source,
+    force_instance, get_doc, get_view_model, is_basic_type, is_field, is_serializer,
+    resolve_regex_path_parameter, resolve_type_hint, safe_ref, warn,
 )
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.types import OpenApiTypes
@@ -119,6 +122,7 @@ class AutoSchema(ViewInspector):
 
     def _process_override_parameters(self):
         result = []
+        exclusions = []
         for parameter in self.get_override_parameters():
             if isinstance(parameter, OpenApiParameter):
                 if is_basic_type(parameter.type):
@@ -127,15 +131,20 @@ class AutoSchema(ViewInspector):
                     schema = self.resolve_serializer(parameter.type, 'request').ref
                 else:
                     schema = parameter.type
-                result.append(build_parameter_type(
-                    name=parameter.name,
-                    schema=schema,
-                    location=parameter.location,
-                    required=parameter.required,
-                    description=parameter.description,
-                    enum=parameter.enum,
-                    deprecated=parameter.deprecated,
-                ))
+
+                if parameter.exclude:
+                    exclusions.append((parameter.name, parameter.location))
+                else:
+                    result.append(build_parameter_type(
+                        name=parameter.name,
+                        schema=schema,
+                        location=parameter.location,
+                        required=parameter.required,
+                        description=parameter.description,
+                        enum=parameter.enum,
+                        deprecated=parameter.deprecated,
+                        examples=build_examples_list(parameter.examples),
+                    ))
             elif is_serializer(parameter):
                 # explode serializer into separate parameters. defaults to QUERY location
                 mapped = self._map_serializer(parameter, 'request')
@@ -144,11 +153,11 @@ class AutoSchema(ViewInspector):
                         name=property_name,
                         schema=property_schema,
                         location=OpenApiParameter.QUERY,
-                        required=property_name in mapped.get('required', [])
+                        required=property_name in mapped.get('required', []),
                     ))
             else:
                 warn(f'could not resolve parameter annotation {parameter}. skipping.')
-        return result
+        return result, exclusions
 
     def _get_format_parameters(self):
         parameters = []
@@ -166,7 +175,8 @@ class AutoSchema(ViewInspector):
         def dict_helper(parameters):
             return {(p['name'], p['in']): p for p in parameters}
 
-        override_parameters = dict_helper(self._process_override_parameters())
+        override_parameters, excluded_parameters = self._process_override_parameters()
+        override_parameters = dict_helper(override_parameters)
         # remove overridden path parameters beforehand so that there are no irrelevant warnings.
         path_variables = [
             v for v in uritemplate.variables(self.path) if (v, 'path') not in override_parameters
@@ -178,6 +188,8 @@ class AutoSchema(ViewInspector):
             **dict_helper(self._get_format_parameters()),
         }
         # override/add @extend_schema parameters
+        for key in excluded_parameters:
+            del parameters[key]
         for key, parameter in override_parameters.items():
             parameters[key] = parameter
 
@@ -336,7 +348,11 @@ class AutoSchema(ViewInspector):
 
         parameters = []
         for filter_backend in self.view.filter_backends:
-            parameters += filter_backend().get_schema_operation_parameters(self.view)
+            filter_extension = OpenApiFilterExtension.get_match(filter_backend())
+            if filter_extension:
+                parameters += filter_extension.get_schema_operation_parameters(self)
+            else:
+                parameters += filter_backend().get_schema_operation_parameters(self.view)
         return parameters
 
     def _get_pagination_parameters(self):
@@ -347,7 +363,11 @@ class AutoSchema(ViewInspector):
         if not paginator:
             return []
 
-        return paginator.get_schema_operation_parameters(self.view)
+        filter_extension = OpenApiFilterExtension.get_match(paginator)
+        if filter_extension:
+            return filter_extension.get_schema_operation_parameters(self)
+        else:
+            return paginator.get_schema_operation_parameters(self.view)
 
     def _map_model_field(self, model_field, direction):
         assert isinstance(model_field, models.Field)
@@ -703,16 +723,16 @@ class AutoSchema(ViewInspector):
                 attr_name = 'maxLength'
                 if isinstance(field, serializers.ListField):
                     attr_name = 'maxItems'
-                schema[attr_name] = v.limit_value
+                schema[attr_name] = v.limit_value() if callable(v.limit_value) else v.limit_value
             elif isinstance(v, validators.MinLengthValidator):
                 attr_name = 'minLength'
                 if isinstance(field, serializers.ListField):
                     attr_name = 'minItems'
-                schema[attr_name] = v.limit_value
+                schema[attr_name] = v.limit_value() if callable(v.limit_value) else v.limit_value
             elif isinstance(v, validators.MaxValueValidator):
-                schema['maximum'] = v.limit_value
+                schema['maximum'] = v.limit_value() if callable(v.limit_value) else v.limit_value
             elif isinstance(v, validators.MinValueValidator):
-                schema['minimum'] = v.limit_value
+                schema['minimum'] = v.limit_value() if callable(v.limit_value) else v.limit_value
             elif isinstance(v, validators.DecimalValidator):
                 if v.max_digits:
                     digits = v.max_digits
@@ -785,6 +805,32 @@ class AutoSchema(ViewInspector):
                 f'a request? Ignoring the view for now. (Exception: {exc})'
             )
 
+    def get_examples(self):
+        return []
+
+    def _get_examples(self, serializer, direction, media_type, status_code=None):
+        examples = self.get_examples()
+
+        if not examples:
+            if isinstance(serializer, serializers.ListSerializer):
+                examples = get_override(serializer.child, 'examples', [])
+            elif is_serializer(serializer):
+                examples = get_override(serializer, 'examples', [])
+
+        filtered_examples = []
+        for example in examples:
+            if direction == 'request' and example.response_only:
+                continue
+            if direction == 'response' and example.request_only:
+                continue
+            if media_type and media_type != example.media_type:
+                continue
+            if status_code and status_code not in example.status_codes:
+                continue
+            filtered_examples.append(example)
+
+        return build_examples_list(filtered_examples)
+
     def _get_request_body(self):
         # only unsafe methods can have a body
         if self.method not in ('PUT', 'PATCH', 'POST'):
@@ -828,9 +874,14 @@ class AutoSchema(ViewInspector):
 
         request_body = {
             'content': {
-                request_media_types: {'schema': schema} for request_media_types in self.map_parsers()
+                media_type: build_media_type_object(
+                    schema,
+                    self._get_examples(serializer, 'request', media_type)
+                )
+                for media_type in self.map_parsers()
             }
         }
+
         if request_body_required:
             request_body['required'] = request_body_required
 
@@ -843,14 +894,22 @@ class AutoSchema(ViewInspector):
             if self.method == 'DELETE':
                 return {'204': {'description': _('No response body')}}
             if self.method == 'POST' and getattr(self.view, 'action', None) == 'create':
-                return {'201': self._get_response_for_code(response_serializers)}
-            return {'200': self._get_response_for_code(response_serializers)}
+                return {'201': self._get_response_for_code(response_serializers, '201')}
+            return {'200': self._get_response_for_code(response_serializers, '200')}
         elif isinstance(response_serializers, dict):
             # custom handling for overriding default return codes with @extend_schema
-            return {
-                str(code): self._get_response_for_code(serializer)
-                for code, serializer in response_serializers.items()
-            }
+            responses = {}
+            for code, serializer in response_serializers.items():
+                if isinstance(code, tuple):
+                    code, media_types = str(code[0]), code[1:]
+                else:
+                    code, media_types = str(code), None
+                content_response = self._get_response_for_code(serializer, code, media_types)
+                if code in responses:
+                    responses[code]['content'].update(content_response['content'])
+                else:
+                    responses[code] = content_response
+            return responses
         else:
             warn(
                 f'could not resolve "{response_serializers}" for {self.method} {self.path}. '
@@ -859,9 +918,9 @@ class AutoSchema(ViewInspector):
             )
             schema = build_basic_type(OpenApiTypes.OBJECT)
             schema['description'] = _('Unspecified response body')
-            return {'200': self._get_response_for_code(schema)}
+            return {'200': self._get_response_for_code(schema, '200')}
 
-    def _get_response_for_code(self, serializer):
+    def _get_response_for_code(self, serializer, status_code, media_types=None):
         serializer = force_instance(serializer)
 
         if not serializer:
@@ -900,16 +959,23 @@ class AutoSchema(ViewInspector):
                     name=paginated_name,
                     type=ResolvedComponent.SCHEMA,
                     schema=paginator.get_paginated_response_schema(schema),
-                    object=paginated_name,
+                    object=serializer,
                 )
-                self.registry.register(component)
+                self.registry.register_on_missing(component)
                 schema = component.ref
             elif paginator:
                 schema = paginator.get_paginated_response_schema(schema)
 
+        if not media_types:
+            media_types = self.map_renderers('media_type')
+
         return {
             'content': {
-                mt: {'schema': schema} for mt in self.map_renderers('media_type')
+                media_type: build_media_type_object(
+                    schema,
+                    self._get_examples(serializer, 'response', media_type, status_code)
+                )
+                for media_type in media_types
             },
             # Description is required by spec, but descriptions for each response code don't really
             # fit into our model. Description is therefore put into the higher level slots.
