@@ -188,6 +188,32 @@ def build_object_type(
     return schema
 
 
+def build_media_type_object(schema, examples=None):
+    media_type_object = {'schema': schema}
+    if examples:
+        media_type_object['examples'] = examples
+    return media_type_object
+
+
+def build_examples_list(examples):
+    schema = {}
+    for example in examples:
+        normalized_name = inflection.camelize(example.name.replace(' ', '_'))
+        sub_schema = {}
+        if example.value:
+            sub_schema['value'] = example.value
+        if example.external_value:
+            sub_schema['externalValue'] = example.external_value
+        if example.summary:
+            sub_schema['summary'] = example.summary
+        elif normalized_name != example.name:
+            sub_schema['summary'] = example.name
+        if example.description:
+            sub_schema['description'] = example.description
+        schema[normalized_name] = sub_schema
+    return schema
+
+
 def build_parameter_type(
         name,
         schema,
@@ -197,9 +223,12 @@ def build_parameter_type(
         enum=None,
         deprecated=False,
         explode=None,
-        style=None
+        style=None,
+        examples=None,
 ):
-    irrelevant_field_meta = ['readOnly', 'writeOnly', 'nullable', 'default']
+    irrelevant_field_meta = ['readOnly', 'writeOnly']
+    if location == OpenApiParameter.PATH:
+        irrelevant_field_meta += ['nullable', 'default']
     schema = {
         'in': location,
         'name': name,
@@ -217,6 +246,8 @@ def build_parameter_type(
         schema['style'] = style
     if enum:
         schema['schema']['enum'] = sorted(enum)
+    if examples:
+        schema['examples'] = examples
     return schema
 
 
@@ -406,7 +437,7 @@ class ComponentRegistry:
         self._components = {}
 
     def register(self, component: ResolvedComponent):
-        if component.key in self._components:
+        if component in self:
             warn(
                 f'trying to re-register a {component.type} component with name '
                 f'{self._components[component.key].name}. this might lead to '
@@ -415,7 +446,7 @@ class ComponentRegistry:
         self._components[component.key] = component
 
     def register_on_missing(self, component: ResolvedComponent):
-        if component.key not in self._components:
+        if component not in self:
             self._components[component.key] = component
 
     def __contains__(self, component):
@@ -763,7 +794,9 @@ def resolve_type_hint(hint):
     if origin is None and is_basic_type(hint, allow_none=False):
         return build_basic_type(hint)
     elif origin is list or hint is list:
-        return build_array_type(build_basic_type(args[0] if args else OpenApiTypes.OBJECT))
+        return build_array_type(
+            resolve_type_hint(args[0]) if args else build_basic_type(OpenApiTypes.OBJECT)
+        )
     elif origin is tuple:
         return build_array_type(
             schema=build_basic_type(args[0]),
@@ -772,7 +805,7 @@ def resolve_type_hint(hint):
         )
     elif origin is dict or origin is defaultdict or origin is OrderedDict:
         schema = build_basic_type(OpenApiTypes.OBJECT)
-        if args[1] is not typing.Any:
+        if args and args[1] is not typing.Any:
             schema['additionalProperties'] = resolve_type_hint(args[1])
         return schema
     elif origin is set:
