@@ -8,6 +8,7 @@ from django.urls import path, re_path
 from rest_framework import (
     filters, generics, mixins, pagination, parsers, routers, serializers, views, viewsets,
 )
+from rest_framework.authentication import TokenAuthentication
 from rest_framework.decorators import action, api_view
 from rest_framework.views import APIView
 
@@ -18,7 +19,7 @@ from drf_spectacular.openapi import AutoSchema
 from drf_spectacular.types import OpenApiTypes
 from drf_spectacular.utils import (
     OpenApiParameter, extend_schema, extend_schema_field, extend_schema_serializer,
-    inline_serializer,
+    extend_schema_view, inline_serializer,
 )
 from drf_spectacular.validation import validate_schema
 from tests import generate_schema, get_request_schema, get_response_schema
@@ -1028,6 +1029,31 @@ def test_pagination(no_warnings):
     assert substitution['properties']['results']['items']['$ref'] == '#/components/schemas/X'
 
 
+def test_pagination_reusage(no_warnings):
+    class M7(models.Model):
+        pass
+
+    class XSerializer(serializers.ModelSerializer):
+        class Meta:
+            fields = '__all__'
+            model = M7
+
+    class XViewset(viewsets.ReadOnlyModelViewSet):
+        queryset = M7.objects.all()
+        serializer_class = XSerializer
+        pagination_class = pagination.LimitOffsetPagination
+
+    class YViewset(XViewset):
+        serializer_class = XSerializer
+
+    router = routers.SimpleRouter()
+    router.register('x', XViewset, basename='x')
+    router.register('y', YViewset, basename='y')
+    generator = SchemaGenerator(patterns=router.urls)
+    schema = generator.get_schema(request=None, public=True)
+    validate_schema(schema)
+
+
 @mock.patch(
     'drf_spectacular.settings.spectacular_settings.SECURITY',
     [{'apiKeyAuth': []}]
@@ -1068,3 +1094,74 @@ def test_basic_viewset_without_queryset_with_explicit_pk_typing(no_warnings):
     operation = schema['paths']['/api/{some_var}/{id}/']['get']
     assert operation['parameters'][0]['name'] == 'id'
     assert operation['parameters'][0]['schema']['format'] == 'uuid'
+
+
+def test_multiple_media_types(no_warnings):
+    @extend_schema(responses={
+        (200, 'application/json'): OpenApiTypes.OBJECT,
+        (200, 'application/pdf'): OpenApiTypes.BINARY,
+    })
+    class XAPIView(APIView):
+        def get(self, request):
+            pass  # pragma: no cover
+
+    schema = generate_schema('x', view=XAPIView)
+    content = schema['paths']['/x']['get']['responses']['200']['content']
+    assert content['application/pdf']['schema']['format'] == 'binary'
+    assert content['application/json']['schema']['type'] == 'object'
+
+
+def test_token_auth_with_bearer_keyword(no_warnings):
+    class CustomTokenAuthentication(TokenAuthentication):
+        keyword = 'Bearer'
+
+    @extend_schema(responses=OpenApiTypes.FLOAT)
+    @api_view(['GET'])
+    def view_func(request, format=None):
+        pass  # pragma: no cover
+    view_func.cls.authentication_classes = [CustomTokenAuthentication]
+
+    schema = generate_schema('x', view_function=view_func)
+    assert schema['components']['securitySchemes']['tokenAuth']['scheme'] == 'bearer'
+
+
+@pytest.mark.parametrize('responses', [
+    str,
+    OpenApiTypes.STR,
+    {'200': str},
+    {'200': OpenApiTypes.STR},
+])
+def test_string_response_variations(no_warnings, responses):
+    @extend_schema(responses=responses)
+    @api_view(['GET'])
+    def view_func(request, format=None):
+        pass  # pragma: no cover
+
+    schema = generate_schema('x', view_function=view_func)
+    assert get_response_schema(schema['paths']['/x']['get'])['type'] == 'string'
+
+
+def test_exclude_discovered_parameter(no_warnings):
+    class M8(models.Model):
+        pass
+
+    class XSerializer(serializers.ModelSerializer):
+        class Meta:
+            fields = '__all__'
+            model = M8
+
+    @extend_schema_view(list=extend_schema(parameters=[
+        # keep 'offset', remove 'limit', and add 'random'
+        OpenApiParameter('limit', exclude=True),
+        OpenApiParameter('random', bool),
+    ]))
+    class XViewset(viewsets.ReadOnlyModelViewSet):
+        queryset = M8.objects.all()
+        serializer_class = XSerializer
+        pagination_class = pagination.LimitOffsetPagination
+
+    schema = generate_schema('x', XViewset)
+    parameters = schema['paths']['/x/']['get']['parameters']
+    assert len(parameters) == 2
+    assert parameters[0]['name'] == 'offset'
+    assert parameters[1]['name'] == 'random'
