@@ -11,11 +11,11 @@ from rest_framework.views import APIView
 
 from drf_spectacular.generators import SchemaGenerator
 from drf_spectacular.types import OpenApiTypes
-from drf_spectacular.utils import extend_schema, extend_schema_view
+from drf_spectacular.utils import PolymorphicProxySerializer, extend_schema, extend_schema_view
 from tests import generate_schema
 
 
-def test_serializer_name_reuse(warnings):
+def test_serializer_name_reuse(capsys):
     from rest_framework import routers
 
     from drf_spectacular.generators import SchemaGenerator
@@ -29,7 +29,7 @@ def test_serializer_name_reuse(warnings):
 
     def x2():
         class XSerializer(serializers.Serializer):
-            integer = serializers.IntegerField
+            integer = serializers.IntegerField()
 
         return XSerializer
 
@@ -46,6 +46,9 @@ def test_serializer_name_reuse(warnings):
     generator = SchemaGenerator(patterns=router.urls)
     generator.get_schema(request=None, public=True)
 
+    stderr = capsys.readouterr().err
+    assert 'Encountered 2 components with identical names "X" and different classes' in stderr
+
 
 def test_owned_serializer_naming_override_with_ref_name_collision(warnings):
     class XSerializer(serializers.Serializer):
@@ -248,3 +251,34 @@ def test_extend_schema_view_on_missing_view_method(capsys):
     generate_schema('x', view=XAPIView)
     stderr = capsys.readouterr().err
     assert '@extend_schema_view argument "post" was not found on view' in stderr
+
+
+def test_polymorphic_proxy_subserializer_missing_type_field(capsys):
+    class IncompleteSerializer(serializers.Serializer):
+        field = serializers.IntegerField()  # missing field named type
+
+    class XAPIView(APIView):
+        @extend_schema(
+            responses=PolymorphicProxySerializer(
+                component_name='Broken',
+                serializers=[IncompleteSerializer],
+                resource_type_field_name='type',
+            )
+        )
+        def get(self, request):
+            pass  # pragma: no cover
+
+    generate_schema('x', view=XAPIView)
+    stderr = capsys.readouterr().err
+    assert 'sub-serializer Incomplete of Broken must contain' in stderr
+
+
+def test_warning_operation_id_on_extend_schema_view(capsys):
+    @extend_schema(operation_id='Invalid', responses=int)
+    class XAPIView(APIView):
+        def get(self, request):
+            pass  # pragma: no cover
+
+    generate_schema('x', view=XAPIView)
+    stderr = capsys.readouterr().err
+    assert 'using @extend_schema on viewset class XAPIView with parameters' in stderr
